==> mdm-rpc-0.1.5-sources.jar: com/chinayanghe/msp/mdm/vo/role/RoleBasicInformationVo.java <==
package com.chinayanghe.msp.mdm.vo.role;

import java.util.Date;

/**
 * Created by Administrator on 2017/4/27 0027.
 */
public class RoleBasicInformationVo {
    //主键
    private String id;
    //角色名称
    private String roleName;
    //角色编码
    private String roleCode;
    //创建时间
    private java.util.Date createDate;
    //创建人ID
    private java.lang.String createName;
    //修改时间
    private java.util.Date updateDate;
    //修改人
    private java.lang.String updateName;
    //状态 0删除 1正常
    private Integer enableStatus;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getRoleName() {
        return roleName;
    }

    public void setRoleName(String roleName) {
        this.roleName = roleName;
    }

    public String getRoleCode() {
        return roleCode;
    }

    public void setRoleCode(String roleCode) {
        this.roleCode = roleCode;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }
}

==> mdm-rpc-0.1.30-sources.jar: com/chinayanghe/msp/mdm/vo/role/RoleBasicInformationVo.java <==
package com.chinayanghe.msp.mdm.vo.role;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by Administrator on 2017/4/27 0027.
 */
public class RoleBasicInformationVo implements Serializable {
    private static final long serialVersionUID = -6487853235843299343L;
    //主键
    private String id;
    //角色名称
    private String roleName;
    //角色编码
    private String roleCode;
    //创建时间
    private java.util.Date createDate;
    //创建人ID
    private java.lang.String createName;
    //修改时间
    private java.util.Date updateDate;
    //修改人
    private java.lang.String updateName;
    //状态 0删除 1正常
    private Integer enableStatus;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getRoleName() {
        return roleName;
    }

    public void setRoleName(String roleName) {
        this.roleName = roleName;
    }

    public String getRoleCode() {
        return roleCode;
    }

    public void setRoleCode(String roleCode) {
        this.roleCode = roleCode;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }
}
